@@ -1,3 +1,5 @@
+/* $Id: procmem.h,v 1.23 2004/12/06 14:44:10 bdejean Exp $ */
+
 /* Copyright (C) 1998-99 Martin Baulig
    This file is part of LibGTop 1.0.
 
@@ -42,18 +44,18 @@ typedef struct _glibtop_proc_mem	glibtop_proc_mem;
 
 struct _glibtop_proc_mem
 {
-	guint64	flags;
-	guint64 size;		/* total # of pages of memory */
-	guint64 vsize;		/* number of pages of virtual memory ... */
-	guint64 resident;	/* number of resident set
+	guint64	flags,
+		size,		/* total # of pages of memory */
+		vsize,		/* number of pages of virtual memory ... */
+		resident,	/* number of resident set
 				 * (non-swapped) pages (4k) */
-	guint64 share;		/* number of pages of shared (mmap'd) memory */
-	guint64 rss;		/* resident set size */
-	guint64 rss_rlim;	/* current limit (in bytes) of the rss
+		share,		/* number of pages of shared (mmap'd) memory */
+		rss,		/* resident set size */
+		rss_rlim;	/* current limit (in bytes) of the rss
 				 * of the process; usually 2,147,483,647 */
 };
 
-void glibtop_get_proc_mem(glibtop_proc_mem *buf, pid_t pid);
+#define glibtop_get_proc_mem(p1, p2)	glibtop_get_proc_mem_l(glibtop_global_server, p1, p2)
 
 #if GLIBTOP_SUID_PROC_MEM
 #define glibtop_get_proc_mem_r		glibtop_get_proc_mem_p
@@ -64,10 +66,10 @@ void glibtop_get_proc_mem(glibtop_proc_mem *buf, pid_t pid);
 void glibtop_get_proc_mem_l (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 
 #if GLIBTOP_SUID_PROC_MEM
-void _glibtop_init_proc_mem_p (glibtop *server);
+void glibtop_init_proc_mem_p (glibtop *server);
 void glibtop_get_proc_mem_p (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 #else
-void _glibtop_init_proc_mem_s (glibtop *server);
+void glibtop_init_proc_mem_s (glibtop *server);
 void glibtop_get_proc_mem_s (glibtop *server, glibtop_proc_mem *buf, pid_t pid);
 #endif
 
